@@ -1,6 +1,6 @@
 package Fey::Meta::Class::Table;
 BEGIN {
-  $Fey::Meta::Class::Table::VERSION = '0.38';
+  $Fey::Meta::Class::Table::VERSION = '0.39';
 }
 
 use strict;
@@ -20,6 +20,8 @@ use Fey::Meta::HasMany::ViaFK;
 use Fey::Meta::HasMany::ViaSelect;
 use Fey::Meta::Method::Constructor;
 use Fey::Meta::Method::FromSelect;
+use Fey::ORM::Types
+    qw( Bool ClassName CodeRef DoesHasMany DoesHasOne HashRef Object );
 use List::AllUtils qw( all );
 
 use Moose qw( extends with has );
@@ -31,7 +33,7 @@ extends 'Moose::Meta::Class';
 class_has '_ClassToTableMap' => (
     traits  => ['Hash'],
     is      => 'ro',
-    isa     => 'HashRef[Fey::Table]',
+    isa     => HashRef ['Fey::Table'],
     default => sub { {} },
     lazy    => 1,
     handles => {
@@ -43,14 +45,14 @@ class_has '_ClassToTableMap' => (
 
 has '_object_cache_is_enabled' => (
     is      => 'rw',
-    isa     => 'Bool',
+    isa     => Bool,
     lazy    => 1,
     default => 0,
 );
 
 has '_object_cache' => (
     is      => 'ro',
-    isa     => 'HashRef',
+    isa     => HashRef [Object],
     lazy    => 1,
     default => sub { {} },
     clearer => '_clear_object_cache',
@@ -66,7 +68,7 @@ has 'table' => (
 has 'inflators' => (
     traits  => ['Hash'],
     is      => 'ro',
-    isa     => 'HashRef[CodeRef]',
+    isa     => HashRef [CodeRef],
     default => sub { {} },
     lazy    => 1,
     handles => {
@@ -78,7 +80,7 @@ has 'inflators' => (
 has 'deflators' => (
     traits  => ['Hash'],
     is      => 'ro',
-    isa     => 'HashRef[CodeRef]',
+    isa     => HashRef [CodeRef],
     default => sub { {} },
     lazy    => 1,
     handles => {
@@ -90,7 +92,7 @@ has 'deflators' => (
 
 has 'schema_class' => (
     is      => 'ro',
-    isa     => 'ClassName',
+    isa     => ClassName,
     lazy    => 1,
     default => sub {
         Fey::Meta::Class::Schema->ClassForSchema( $_[0]->table()->schema() );
@@ -106,7 +108,7 @@ has 'policy' => (
 has '_has_ones' => (
     traits  => ['Hash'],
     is      => 'ro',
-    isa     => 'HashRef[Fey::Meta::HasOne]',
+    isa     => HashRef [DoesHasOne],
     default => sub { {} },
     lazy    => 1,
     handles => {
@@ -121,7 +123,7 @@ has '_has_ones' => (
 has '_has_manies' => (
     traits  => ['Hash'],
     is      => 'ro',
-    isa     => 'HashRef[Fey::Meta::HasMany]',
+    isa     => HashRef [DoesHasMany],
     default => sub { {} },
     lazy    => 1,
     handles => {
@@ -142,7 +144,7 @@ has '_select_sql_cache' => (
 
 has '_sql_string_cache' => (
     is      => 'ro',
-    isa     => 'HashRef[HashRef]',
+    isa     => HashRef [HashRef],
     lazy    => 1,
     default => sub {
         { {} }
@@ -327,9 +329,10 @@ sub _add_transform {
     param_error "The column $name does not exist as an attribute"
         unless $attr;
 
-    $self->_add_inflator_to_attribute( $name, $attr, $p{inflate},
-        $p{handles} )
-        if $p{inflate};
+    $self->_add_inflator_to_attribute(
+        $name, $attr, $p{inflate},
+        $p{handles}
+    ) if $p{inflate};
 
     if ( $p{deflate} ) {
         param_error
@@ -540,7 +543,7 @@ Fey::Meta::Class::Table - A metaclass for table classes
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
