@@ -1,14 +1,16 @@
 package Fey::Meta::Role::FromSelect;
 BEGIN {
-  $Fey::Meta::Role::FromSelect::VERSION = '0.38';
+  $Fey::Meta::Role::FromSelect::VERSION = '0.39';
 }
 
 use strict;
 use warnings;
 use namespace::autoclean;
 
+use Fey::ORM::Types qw( Bool CodeRef );
+use Moose::Util::TypeConstraints qw( find_type_constraint );
+
 use Moose::Role;
-use Moose::Util::TypeConstraints;
 
 has select => (
     is       => 'ro',
@@ -18,12 +20,12 @@ has select => (
 
 has bind_params => (
     is  => 'ro',
-    isa => 'CodeRef',
+    isa => CodeRef,
 );
 
 has is_multi_column => (
     is      => 'ro',
-    isa     => 'Bool',
+    isa     => Bool,
     default => 0,
 );
 
