@@ -1,6 +1,6 @@
 package Fey::Object::Iterator::FromSelect;
 BEGIN {
-  $Fey::Object::Iterator::FromSelect::VERSION = '0.38';
+  $Fey::Object::Iterator::FromSelect::VERSION = '0.39';
 }
 
 use strict;
@@ -8,6 +8,7 @@ use warnings;
 use namespace::autoclean;
 
 use Fey::Exceptions qw( param_error );
+use Fey::ORM::Types qw( ArrayRef HashRef Maybe Str );
 
 use Devel::GlobalDestruction;
 use Moose;
@@ -30,7 +31,7 @@ has select => (
 
 has bind_params => (
     is      => 'ro',
-    isa     => 'ArrayRef',
+    isa     => ArrayRef,
     lazy    => 1,
     default => sub { [ $_[0]->select()->bind_params() ] },
 );
@@ -48,13 +49,13 @@ has _sth => (
 
 has 'attribute_map' => (
     is      => 'ro',
-    isa     => 'HashRef[HashRef[Str]]',
+    isa     => HashRef [ HashRef [Str] ],
     default => sub { return {} },
 );
 
 has _class_attributes_by_position => (
     is       => 'ro',
-    isa      => 'HashRef[HashRef[Str]]',
+    isa      => HashRef [ HashRef [Str] ],
     init_arg => undef,
     lazy     => 1,
     builder  => '_build_class_attributes_by_position',
@@ -62,7 +63,7 @@ has _class_attributes_by_position => (
 
 has raw_row => (
     is       => 'rw',
-    isa      => 'Maybe[ArrayRef]',
+    isa      => Maybe [ArrayRef],
     init_arg => undef,
     writer   => '_set_raw_row',
 );
@@ -225,7 +226,7 @@ Fey::Object::Iterator::FromSelect - Wraps a DBI statement handle to construct ob
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
